This function copies a .lintr configuration file to a new script in a specified location.
addLintrConfig(outFile = ".lintr")Character scalar, giving the path to which the script
should be copied. The path is relative to the root of the active
project. If a file with this name already exists, the function will
ask for confirmation before overwriting it. outFile will also
be added to the .Rbuildignore and .gitignore files.