R/RcppExports.R
calcAndCountDist.RdGiven two ascendingly sorted integer vectors query and reference, calculate
and count the differences between their elements that are greater than zero
and less than maxd. The number of observed distances d are reported in cnt[d],
and maxd corresponds to the length(cnt). The function is
called by calcPhasogram, which provides a higher level, more
conventient interface.
calcAndCountDist(query, reference, cnt)first integer vector.
second integer vector. Distances are calculated from each element
in query to each greater element in reference.
NumericVector to store the result in. The length of cnt defines
the maximal distance that will be included in the analysis, and new counts
will be added to the values of cnt.
numeric vector cnt, where cnt[d] correspond to
the number of observed distances d.